##  Activating the Dashboard
Admin users can activate the onboarding dashboard and make it available to all workspace users as a template. To do that, navigate to the Dashboards section in the administration area, locate the Templates settings group, then click Add template for the Fact Sheet Owner Onboarding Dashboard template and confirm your action.
For more information, see [Dashboard Templates](https://help.sap.com/docs/leanix/ea/dashboards-settings?locale=en-US&state=PRODUCTION&version=CLOUD#loio2759a5e37a441014acd0dfe4da61c1c5__dashboard_templates).
